@@ -23,11 +23,11 @@ gather_samples = function(...) {
 #' @importFrom dplyr bind_rows group_by_at
 #' @importFrom rlang enquos
 #' @export
-gather_draws = function(model, ..., regex = FALSE, sep = "[, ]") {
+gather_draws = function(model, ..., regex = FALSE, sep = "[, ]", n = NULL, seed = NULL) {
+  draws = sample_draws_from_model_(model, n, seed)
+
   tidysamples = lapply(enquos(...), function(variable_spec) {
-    model %>%
-      spread_draws_(variable_spec, regex = regex, sep = sep) %>%
-      gather_variables()
+    gather_variables(spread_draws_(draws, variable_spec, regex = regex, sep = sep))
   })
 
   #get the groups from all the samples --- when we bind them together,
