@@ -45,73 +45,73 @@ spread_samples = function(...) {
 #' Extract draws from a Bayesian model for one or more variables (possibly with named
 #' dimensions) into one of two types of long-format data frames.
 #'
-#' Imagine a JAGS or Stan fit named \code{fit}. The model may contain a variable named
-#' \code{b[i,v]} (in the JAGS or Stan language) with dimension \code{i} in \code{1:100} and
-#' dimension \code{v} in \code{1:3}. However, the default format for draws returned from
+#' Imagine a JAGS or Stan fit named `fit`. The model may contain a variable named
+#' `b[i,v]` (in the JAGS or Stan language) with dimension `i` in `1:100` and
+#' dimension `v` in `1:3`. However, the default format for draws returned from
 #' JAGS or Stan in R will not reflect this indexing structure, instead
-#' they will have multiple columns with names like \code{"b[1,1]"}, \code{"b[2,1]"}, etc.
+#' they will have multiple columns with names like `"b[1,1]"`, `"b[2,1]"`, etc.
 #'
-#' \code{spread_draws} and \code{gather_draws} provide a straightforward
+#' `spread_draws` and `gather_draws` provide a straightforward
 #' syntax to translate these columns back into properly-indexed variables in two different
 #' tidy data frame formats, optionally recovering dimension types (e.g. factor levels) as it does so.
 #'
-#' \code{spread_draws} and \code{gather_draws} return data frames already grouped by
+#' `spread_draws` and `gather_draws` return data frames already grouped by
 #' all dimensions used on the variables you specify.
 #'
-#' The difference between \code{spread_draws} is that names of variables in the model will
-#' be spread across the data frame as column names, whereas \code{gather_draws} will
-#' gather variables into a single column named \code{".variable"} and place values of variables into a
-#' column named \code{".value"}. To use naming schemes from other packages (such as \code{broom}), consider passing
-#' results through functions like \code{\link{to_broom_names}} or \code{\link{to_ggmcmc_names}}.
+#' The difference between `spread_draws` is that names of variables in the model will
+#' be spread across the data frame as column names, whereas `gather_draws` will
+#' gather variables into a single column named `".variable"` and place values of variables into a
+#' column named `".value"`. To use naming schemes from other packages (such as `broom`), consider passing
+#' results through functions like [to_broom_names()] or [to_ggmcmc_names()].
 #'
-#' For example, \code{spread_draws(fit, a[i], b[i,v])} might return a grouped
-#' data frame (grouped by \code{i} and \code{v}), with:
+#' For example, `spread_draws(fit, a[i], b[i,v])` might return a grouped
+#' data frame (grouped by `i` and `v`), with:
 #' \itemize{
-#'    \item column \code{".chain"}: the chain number. \code{NA} if not applicable to the model
+#'    \item column `".chain"`: the chain number. `NA` if not applicable to the model
 #'      type; this is typically only applicable to MCMC algorithms.
-#'    \item column \code{".iteration"}: the iteration number. Guaranteed to be unique within-chain only.
-#'      \code{NA} if not applicable to the model type; this is typically only applicable to MCMC algorithms.
-#'    \item column \code{".draw"}: a unique number for each draw from the posterior. Order is not
+#'    \item column `".iteration"`: the iteration number. Guaranteed to be unique within-chain only.
+#'      `NA` if not applicable to the model type; this is typically only applicable to MCMC algorithms.
+#'    \item column `".draw"`: a unique number for each draw from the posterior. Order is not
 #'      guaranteed to be meaningful.
-#'    \item column \code{"i"}: value in \code{1:5}
-#'    \item column \code{"v"}: value in \code{1:10}
-#'    \item column \code{"a"}: value of \code{"a[i]"} for draw \code{".draw"}
-#'    \item column \code{"b"}: value of \code{"b[i,v]"} for draw \code{".draw"}
+#'    \item column `"i"`: value in `1:5`
+#'    \item column `"v"`: value in `1:10`
+#'    \item column `"a"`: value of `"a[i]"` for draw `".draw"`
+#'    \item column `"b"`: value of `"b[i,v]"` for draw `".draw"`
 #'  }
 #'
-#' \code{gather_draws(fit, a[i], b[i,v])} on the same fit would return a grouped
-#' data frame (grouped by \code{i} and \code{v}), with:
+#' `gather_draws(fit, a[i], b[i,v])` on the same fit would return a grouped
+#' data frame (grouped by `i` and `v`), with:
 #' \itemize{
-#'    \item column \code{".chain"}: the chain number
-#'    \item column \code{".iteration"}: the iteration number
-#'    \item column \code{".draw"}: the draw number
-#'    \item column \code{"i"}: value in \code{1:5}
-#'    \item column \code{"v"}: value in \code{1:10}, or \code{NA}
-#'      if \code{".variable"} is \code{"a"}.
-#'    \item column \code{".variable"}: value in \code{c("a", "b")}.
-#'    \item column \code{".value"}: value of \code{"a[i]"} (when \code{".variable"} is \code{"a"})
-#'      or \code{"b[i,v]"} (when \code{".variable"} is \code{"b"}) for draw \code{".draw"}
+#'    \item column `".chain"`: the chain number
+#'    \item column `".iteration"`: the iteration number
+#'    \item column `".draw"`: the draw number
+#'    \item column `"i"`: value in `1:5`
+#'    \item column `"v"`: value in `1:10`, or `NA`
+#'      if `".variable"` is `"a"`.
+#'    \item column `".variable"`: value in `c("a", "b")`.
+#'    \item column `".value"`: value of `"a[i]"` (when `".variable"` is `"a"`)
+#'      or `"b[i,v]"` (when `".variable"` is `"b"`) for draw `".draw"`
 #'  }
 #'
-#' \code{spread_draws} and \code{gather_draws} can use type information
-#' applied to the \code{fit} object by \code{\link{recover_types}} to convert columns
+#' `spread_draws` and `gather_draws` can use type information
+#' applied to the `fit` object by [recover_types()] to convert columns
 #' back into their original types. This is particularly helpful if some of the dimensions in
-#' your model were originally factors. For example, if the \code{v} dimension
-#' in the original data frame \code{data} was a factor with levels \code{c("a","b","c")},
-#' then we could use \code{recover_types} before \code{spread_draws}:
+#' your model were originally factors. For example, if the `v` dimension
+#' in the original data frame `data` was a factor with levels `c("a","b","c")`,
+#' then we could use `recover_types` before `spread_draws`:
 #'
 #' \preformatted{fit \%>\%
 #'  recover_types(data) %\>\%
 #'  spread_draws(fit, b[i,v])
 #' }
 #'
-#' Which would return the same data frame as above, except the \code{"v"} column
-#' would be a value in \code{c("a","b","c")} instead of \code{1:3}.
+#' Which would return the same data frame as above, except the `"v"` column
+#' would be a value in `c("a","b","c")` instead of `1:3`.
 #'
 #' For variables that do not share the same subscripts (or share
 #' some but not all subscripts), we can supply their specifications separately.
-#' For example, if we have a variable d[i] with the same i subscript
-#' as b[i,v], and a variable x with no subscripts, we could do this:
+#' For example, if we have a variable `d[i]` with the same `i` subscript
+#' as `b[i,v]`, and a variable `x` with no subscripts, we could do this:
 #'
 #' \preformatted{spread_draws(fit, x, d[i], b[i,v])}
 #'
@@ -136,43 +136,43 @@ spread_samples = function(...) {
 #' )}
 #'
 #'
-#' The \code{c} and \code{cbind} functions can be used to combine multiple variable names that have
+#' The `c` and `cbind` functions can be used to combine multiple variable names that have
 #' the same dimensions. For example, if we have several variables with the same
-#' subscripts \code{i} and \code{v}, we could do either of these:
+#' subscripts `i` and `v`, we could do either of these:
 #'
 #' \preformatted{spread_draws(fit, c(w, x, y, z)[i,v])}
-#' \preformatted{spread_draws(fit, cbind(w, x, y, z)[i,v])}  # equivalent
+#' \preformatted{spread_draws(fit, cbind(w, x, y, z)[i,v])  # equivalent}
 #'
 #' Each of which is roughly equivalent to this:
 #'
 #' \preformatted{spread_draws(fit, w[i,v], x[i,v], y[i,v], z[i,v])}
 #'
-#' Besides being more compact, the \code{c()}-style syntax is currently also
+#' Besides being more compact, the `c()`-style syntax is currently also
 #' faster (though that may change).
 #'
 #' Dimensions can be omitted from the resulting data frame by leaving their names
-#' blank; e.g. \code{spread_draws(fit, b[,v])} will omit the first dimension of
-#' \code{b} from the output. This is useful if a dimension is known to contain all
+#' blank; e.g. `spread_draws(fit, b[,v])` will omit the first dimension of
+#' `b` from the output. This is useful if a dimension is known to contain all
 #' the same value in a given model.
 #'
-#' The shorthand \code{..} can be used to specify one column that should be put
+#' The shorthand `..` can be used to specify one column that should be put
 #' into a wide format and whose names will be the base variable name, plus a dot
-#' ("."), plus the value of the dimension at \code{..}. For example:
+#' ("."), plus the value of the dimension at `..`. For example:
 #'
-#' \code{spread_draws(fit, b[i,..])} would return a grouped data frame
-#' (grouped by \code{i}), with:
+#' `spread_draws(fit, b[i,..])` would return a grouped data frame
+#' (grouped by `i`), with:
 #' \itemize{
-#'  \item column \code{".chain"}: the chain number
-#'  \item column \code{".iteration"}: the iteration number
-#'  \item column \code{".draw"}: the draw number
-#'  \item column \code{"i"}: value in \code{1:20}
-#'  \item column \code{"b.1"}: value of \code{"b[i,1]"} for draw \code{".draw"}
-#'  \item column \code{"b.2"}: value of \code{"b[i,2]"} for draw \code{".draw"}
-#'  \item column \code{"b.3"}: value of \code{"b[i,3]"} for draw \code{".draw"}
+#'  \item column `".chain"`: the chain number
+#'  \item column `".iteration"`: the iteration number
+#'  \item column `".draw"`: the draw number
+#'  \item column `"i"`: value in `1:20`
+#'  \item column `"b.1"`: value of `"b[i,1]"` for draw `".draw"`
+#'  \item column `"b.2"`: value of `"b[i,2]"` for draw `".draw"`
+#'  \item column `"b.3"`: value of `"b[i,3]"` for draw `".draw"`
 #' }
 #'
-#' An optional clause in the form \code{| wide_dimension} can also be used to put
-#' the data frame into a wide format based on \code{wide_dimension}. For example, this:
+#' An optional clause in the form `| wide_dimension` can also be used to put
+#' the data frame into a wide format based on `wide_dimension`. For example, this:
 #'
 #' \preformatted{spread_draws(fit, b[i,v] | v)}
 #'
@@ -180,56 +180,62 @@ spread_samples = function(...) {
 #'
 #' \preformatted{spread_draws(fit, b[i,v]) \%>\% spread(v,b)}
 #'
-#' The main difference between using the \code{|} syntax instead of the
-#' \code{..} syntax is that the \code{|} syntax respects prototypes applied to
-#' dimensions with \code{\link{recover_types}}, and thus can be used to get
+#' The main difference between using the `|` syntax instead of the
+#' `..` syntax is that the `|` syntax respects prototypes applied to
+#' dimensions with [recover_types()], and thus can be used to get
 #' columns with nicer names. For example:
 #'
-#' \code{fit \%>\% recover_types(data) \%>\% spread_draws(b[i,v] | v)} would return a grouped data frame
-#' (grouped by \code{i}), with:
+#' ```
+#' fit %>% recover_types(data) %>% spread_draws(b[i,v] | v)
+#' ```
+#'
+#' would return a grouped data frame
+#' (grouped by `i`), with:
 #' \itemize{
-#'  \item column \code{".chain"}: the chain number
-#'  \item column \code{".iteration"}: the iteration number
-#'  \item column \code{".draw"}: the draw number
-#'  \item column \code{"i"}: value in \code{1:20}
-#'  \item column \code{"a"}: value of \code{"b[i,1]"} for draw \code{".draw"}
-#'  \item column \code{"b"}: value of \code{"b[i,2]"} for draw \code{".draw"}
-#'  \item column \code{"c"}: value of \code{"b[i,3]"} for draw \code{".draw"}
+#'  \item column `".chain"`: the chain number
+#'  \item column `".iteration"`: the iteration number
+#'  \item column `".draw"`: the draw number
+#'  \item column `"i"`: value in `1:20`
+#'  \item column `"a"`: value of `"b[i,1]"` for draw `".draw"`
+#'  \item column `"b"`: value of `"b[i,2]"` for draw `".draw"`
+#'  \item column `"c"`: value of `"b[i,3]"` for draw `".draw"`
 #' }
 #'
-#' The shorthand \code{.} can be used to specify columns that should be nested
+#' The shorthand `.` can be used to specify columns that should be nested
 #' into vectors, matrices, or n-dimensional arrays (depending on how many dimensions
-#' are specified with \code{.}).
+#' are specified with `.`).
 #'
-#' For example, \code{spread_draws(fit, a[.], b[.,.])} might return a
+#' For example, `spread_draws(fit, a[.], b[.,.])` might return a
 #' data frame, with:
 #' \itemize{
-#'    \item column \code{".chain"}: the chain number.
-#'    \item column \code{".iteration"}: the iteration number.
-#'    \item column \code{".draw"}: a unique number for each draw from the posterior.
-#'    \item column \code{"a"}: a list column of vectors.
-#'    \item column \code{"b"}: a list column of matrices.
+#'    \item column `".chain"`: the chain number.
+#'    \item column `".iteration"`: the iteration number.
+#'    \item column `".draw"`: a unique number for each draw from the posterior.
+#'    \item column `"a"`: a list column of vectors.
+#'    \item column `"b"`: a list column of matrices.
 #'  }
 #'
 #' Ragged arrays are turned into non-ragged arrays with
-#' missing entries given the value \code{NA}.
+#' missing entries given the value `NA`.
 #'
-#' Finally, variable names can be regular expressions by setting \code{regex = TRUE}; e.g.:
+#' Finally, variable names can be regular expressions by setting `regex = TRUE`; e.g.:
 #'
-#' \code{spread_draws(fit, `b_.*`[i], regex = TRUE)}
+#' \preformatted{spread_draws(fit, `b_.*`[i], regex = TRUE)}
 #'
 #' Would return a tidy data frame with variables starting with `b_` and having one dimension.
 #'
 #' @param model A supported Bayesian model fit. Tidybayes supports a variety of model objects;
-#' for a full list of supported models, see \link{tidybayes-models}.
+#' for a full list of supported models, see [tidybayes-models].
 #' @param ... Expressions in the form of
-#' \code{variable_name[dimension_1, dimension_2, ...] | wide_dimension}. See `Details`.
-#' @param regex If \code{TRUE}, variable names are treated as regular expressions and all column matching the
-#' regular expression and number of dimensions are included in the output. Default \code{FALSE}.
+#' `variable_name[dimension_1, dimension_2, ...] | wide_dimension`. See *Details*.
+#' @param regex If `TRUE`, variable names are treated as regular expressions and all column matching the
+#' regular expression and number of dimensions are included in the output. Default `FALSE`.
 #' @param sep Separator used to separate dimensions in variable names, as a regular expression.
+#' @param n The number of draws to return, or `NULL` to return all draws.
+#' @param seed A seed to use when subsampling draws (i.e. when `n` is not `NULL`).
 #' @return A data frame.
 #' @author Matthew Kay
-#' @seealso \code{\link{recover_types}}, \code{\link{compose_data}}.
+#' @seealso [recover_types()], [compose_data()].
 #' @keywords manip
 #' @examples
 #'
@@ -257,9 +263,11 @@ spread_samples = function(...) {
 #' @importFrom dplyr inner_join group_by_at
 #' @rdname spread_draws
 #' @export
-spread_draws = function(model, ..., regex = FALSE, sep = "[, ]") {
+spread_draws = function(model, ..., regex = FALSE, sep = "[, ]", n = NULL, seed = NULL) {
+  draws = sample_draws_from_model_(model, n, seed)
+
   tidysamples = lapply(enquos(...), function(variable_spec) {
-    spread_draws_(model, variable_spec, regex = regex, sep = sep)
+    spread_draws_(draws, variable_spec, regex = regex, sep = sep)
   })
 
   #get the groups from all the samples --- when we join them together,
@@ -281,7 +289,7 @@ spread_draws = function(model, ..., regex = FALSE, sep = "[, ]") {
 #' @import dplyr
 #' @importFrom tidyr spread_
 #' @importFrom rlang has_name
-spread_draws_ = function(model, variable_spec, regex = FALSE, sep = "[, ]") {
+spread_draws_ = function(draws, variable_spec, regex = FALSE, sep = "[, ]") {
   #parse a variable spec in the form variable_name[dimension_name_1, dimension_name_2, ..] | wide_dimension
   spec = parse_variable_spec(variable_spec)
   variable_names = spec[[1]]
@@ -289,15 +297,15 @@ spread_draws_ = function(model, variable_spec, regex = FALSE, sep = "[, ]") {
   wide_dimension_name = spec[[3]]
 
   #extract the draws into a long format data frame
-  draws = spread_draws_long_(tidy_draws(model), variable_names, dimension_names, regex = regex, sep = sep)
+  long_draws = spread_draws_long_(draws, variable_names, dimension_names, regex = regex, sep = sep)
 
   #convert variable and/or dimensions back into usable data types
-  constructors = attr(model, "constructors")
+  constructors = attr(draws, "tidybayes_constructors")
   if (is.null(constructors)) constructors = list()
   for (column_name in c(variable_names, dimension_names)) {
     if (column_name %in% names(constructors)) {
       #we have a data type constructor for this dimension, convert it
-      draws[[column_name]] = constructors[[column_name]](draws[[column_name]])
+      long_draws[[column_name]] = constructors[[column_name]](long_draws[[column_name]])
     }
   }
 
@@ -308,16 +316,15 @@ spread_draws_ = function(model, variable_spec, regex = FALSE, sep = "[, ]") {
     if (length(variable_names) != 1) {
       stop("Cannot extract draws from multiple variables in wide format.")
     }
-    draws %>%
-      spread_(wide_dimension_name, variable_names)
+    spread_(long_draws, wide_dimension_name, variable_names)
   }
-  else if (has_name(draws, "..")) {
+  else if (has_name(long_draws, "..")) {
     #a column named ".." is present, use it to form a wide version of the data
     #with numbered names based on the variable name
     if (length(variable_names) != 1) {
       stop("Cannot extract draws from multiple variables in wide format.")
     }
-    draws %>%
+    long_draws %>%
       #the ".." column will have been set as a grouping column because it was
       #specified as a dimension; therefore before we can modify it we have to
       #remove it from the grouping columns on this table (mutate does not
@@ -328,14 +335,14 @@ spread_draws_ = function(model, variable_spec, regex = FALSE, sep = "[, ]") {
   }
   else {
     #no wide column => just return long version
-    draws
+    long_draws
   }
 }
 
 ## draws: tidy draws, such as reutrned by tidy_draws()
 ## variable_names: a character vector of names of variables
 ## dimension_names: a character vector of dimension names
-#' @importFrom tidyr spread_ separate_ gather_
+#' @importFrom tidyr spread_ separate gather_
 #' @import dplyr
 spread_draws_long_ = function(draws, variable_names, dimension_names, regex = FALSE, sep = "[, ]") {
   if (!regex) {
@@ -354,7 +361,7 @@ spread_draws_long_ = function(draws, variable_names, dimension_names, regex = FA
     }
 
     variable_names = colnames(draws)[variable_names_index]
-    draws[, c(".chain", ".iteration", ".draw", variable_names)]
+    unnest_legacy(draws[, c(".chain", ".iteration", ".draw", variable_names)])
   }
   else {
     dimension_sep_regex = sep
@@ -403,41 +410,51 @@ spread_draws_long_ = function(draws, variable_names, dimension_names, regex = FA
     # remove nested dimensions from the final grouping dimensions (since they will not be columns after nesting)
     dimension_names = setdiff(dimension_names, c(nested_dimension_names, "."))
 
-    # Make long format data frame of the variables we want to split.
-    # The following code chunk is approximately equivalent to this:
-    #
-    #   long_draws = draws[, c(".chain", ".iteration", ".draw", variable_names)] %>%
-    #     gather_(".variable", ".value", variable_names)
-    #
-    # but takes half as long to run (makes a difference with large samples):
-    long_draws = draws[,c(".chain",".iteration",".draw")] %>%
-      cbind(map_dfr(variable_names, function(variable_name) data.frame(
-        .variable = variable_name,
-        .value = draws[[variable_name]],
-
-        stringsAsFactors = FALSE
-      )))
-
-    long_draws = long_draws %>%
-      #next, split dimensions in variable names into columns
-      separate_(".variable", c(".variable", ".dimensions"), sep = "\\[|\\]") %>%
-      separate_(".dimensions", temp_dimension_names, sep = dimension_sep_regex,
-        convert = TRUE #converts dimensions to numerics if applicable
-      )
+    # Make nested data frame of just the variables we want to split, without chain indices (these are
+    # all the same anyway and carrying them around adds a bunch of overhead). Nesting first makes the time
+    # for separate() depend on the number of parameters instead of number of parameters * number of draws
+    nested_draws = draws[, variable_names] %>%
+      summarise_all(list) %>%
+      gather_(".variable", ".value", variable_names)
 
+    #next, split dimensions in variable names into columns
+    nested_draws = separate(nested_draws, ".variable", c(".variable", ".dimensions"), sep = "\\[|\\]")
+    nested_draws = separate(nested_draws, ".dimensions", temp_dimension_names, sep = dimension_sep_regex,
+      convert = TRUE #converts dimensions to numerics if applicable
+    )
 
+    # Now go to a long format for everything else...
+    # We have three things to accomplish here:
+    # 1. SPREAD so variable names are back as columns
+    # 2. UNNEST so draws and chain info are no longer list columns
+    # 3. ADD CHAIN INFO (.chain, .iteration, .draw) back into the data frame
+    # The order we will take depends on whether or not the user has requested nested columns (e.g.
+    # array output), because order 1/2/3 is fast but doesn't currently work for doing nested columns.
     if (length(nested_dimension_names) > 0) {
-      # some dimensions were requested to be nested as list columns containing arrays
+      # some dimensions were requested to be nested as list columns containing arrays.
+      # thus we have to UNNEST then ADD CHAIN INFO, then NEST DIMENSIONS then SPREAD
+      # 2. UNNEST
+      long_draws = unnest_legacy(nested_draws)
+      # 3. ADD CHAIN INFO
+      long_draws[,c(".chain", ".iteration", ".draw")] = draws[,c(".chain", ".iteration", ".draw")]
+      # NEST DIMENSIONS
       long_draws = nest_dimensions_(long_draws, temp_dimension_names, nested_dimension_names)
+      # 1. SPREAD
+      long_draws = spread(long_draws, ".variable", ".value")
+    } else {
+      # no nested dimensions, so we can do the SPREAD then UNNEST then ADD CHAIN INFO
+      # 1. SPREAD
+      nested_draws = spread(nested_draws, ".variable", ".value")
+      # 2. UNNEST
+      long_draws = unnest_legacy(nested_draws)
+      # 3. ADD CHAIN INFO
+      long_draws[,c(".chain", ".iteration", ".draw")] = draws[,c(".chain", ".iteration", ".draw")]
     }
 
-    long_draws %>%
-      #now, make the value of each variable a column
-      spread_(".variable", ".value") %>%
-      #drop the columns that correpond to blank dimensions in the original spec
-      select(-starts_with(".drop")) %>%
-      #group by the desired dimensions so that we return a pre-grouped data frame to the user
-      group_by_at(dimension_names)
+    #drop the columns that correspond to blank dimensions in the original spec
+    long_draws[, grep("^\\.drop", names(long_draws), value = TRUE)] = NULL
+    #group by the desired dimensions so that we return a pre-grouped data frame to the user
+    group_by_at(long_draws, dimension_names)
   }
 }
 
@@ -460,15 +477,14 @@ nest_dimensions_ = function(long_draws, dimension_names, nested_dimension_names)
     }
   }
 
-  long_draws %<>%
-    group_by_at(
-      c(".chain", ".iteration", ".draw", ".variable", dimension_names) %>%
+  long_draws = group_by_at(long_draws,
+    c(".chain", ".iteration", ".draw", ".variable", dimension_names) %>%
       # nested dimension names must come at the end of the group list
       # (minus the last nested dimension) so that we summarise in the
       # correct order
       setdiff(nested_dimension_names) %>%
       c(nested_dimension_names[-length(nested_dimension_names)])
-    )
+  )
 
   # go from last dimension up
   nested_dimension_names = rev(nested_dimension_names)
@@ -477,8 +493,7 @@ nest_dimensions_ = function(long_draws, dimension_names, nested_dimension_names)
     dimension_name = nested_dimension_names[[i]]
     dimension = as.name(dimension_name)
 
-    long_draws %<>%
-      summarise_at(c(dimension_name, value_name), list)
+    long_draws = summarise_at(long_draws, c(dimension_name, value_name), list)
 
     # pull out the indices from the first draw to verify we can use them as array indices
     first_draw_indices = filter(long_draws, .draw == .draw[[1]])[[dimension_name]]
@@ -557,6 +572,18 @@ nest_dimensions_ = function(long_draws, dimension_names, nested_dimension_names)
 
 # helpers -----------------------------------------------------------------
 
+# sample draws from a model
+sample_draws_from_model_ = function(model, n = NULL, seed = NULL) {
+  draws = tidy_draws(model)
+
+  if (!is.null(n)) {
+    if (!is.null(seed)) set.seed(seed)
+    draws = sample_n(draws, n)
+  }
+
+  draws
+}
+
 # get a string for printing variable names in specs for error
 printable_variable_names = function(variable_names) {
   if (length(variable_names) == 1) {
@@ -568,7 +595,7 @@ printable_variable_names = function(variable_names) {
 
 # get all variable names from an expression
 # based on http://adv-r.had.co.nz/dsl.html
-all_names <- function(x) {
+all_names = function(x) {
   if (is.atomic(x)) {
     NULL
   } else if (is.name(x)) {
@@ -580,7 +607,7 @@ all_names <- function(x) {
       name
     }
   } else if (is.call(x) || is.pairlist(x)) {
-    children <- lapply(x[-1], all_names)
+    children = lapply(x[-1], all_names)
     unique(unlist(children))
   } else {
     stop("Don't know how to handle type `", typeof(x), "`",
@@ -642,9 +669,9 @@ abind0 = function(vectors) {
 # 2. A vector of dimension names (or NULL if none)
 # 3. The name of the wide dimension (or NULL if none)
 #' @importFrom purrr reduce map map2
-#' @importFrom rlang set_names new_data_mask
+#' @importFrom rlang set_names new_data_mask quo_get_expr
 parse_variable_spec = function(variable_spec) {
-  names = all_names(variable_spec[[2]])
+  names = all_names(quo_get_expr(variable_spec))
   #specs for each bare variable name in the spec expression
   names_spec = names %>%
     set_names() %>%
